@@ -1,5 +1,5 @@
 package ex::constant::vars;
-
+$ex::constant::vars::VERSION = '0.06';
 use 5.006;
 use strict;
 use warnings;
@@ -7,8 +7,6 @@ use Carp;
 
 require Exporter;
 
-our $VERSION    = '0.05';
-
 our @ISA        = qw(
                       Exporter
                       ex::constant::vars::scalar
@@ -66,6 +64,7 @@ sub import {
 
 
 package ex::constant::vars::scalar;
+$ex::constant::vars::scalar::VERSION = '0.06';
 use Carp;
 $Carp::CarpLevel = 1;
 sub TIESCALAR { shift; bless \(my $scalar = shift), __PACKAGE__ }
@@ -74,6 +73,7 @@ sub STORE     { croak "Modification of a read-only value attempted" }
 
 
 package ex::constant::vars::array;
+$ex::constant::vars::array::VERSION = '0.06';
 use Carp;
 $Carp::CarpLevel = 1;
 sub TIEARRAY  { shift; bless $_=\@_, __PACKAGE__ }
@@ -86,6 +86,7 @@ sub STORE     { croak "Modification of a read-only value attempted" }
 
 
 package ex::constant::vars::hash;
+$ex::constant::vars::hash::VERSION = '0.06';
 use Carp;
 $Carp::CarpLevel = 1;
 sub TIEHASH  { bless {@_[1...$#_]}, __PACKAGE__ }
@@ -193,7 +194,7 @@ Produces:
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/ex-constant-vars>
+L<https://github.com/neilb/ex-constant-vars>
 
 =head1 AUTHOR
 
